# Checking Headers and Functions for fontconfig

include( CheckIncludeFile )
include( CheckFunctionExists )

if(WIN32)
    if(MSVC)
        set( CMAKE_REQUIRED_INCLUDES ${CMAKE_INCLUDE_PATH} ${CMAKE_INCLUDE_PATH}/msvc )
    else(MSVC)
        set( CMAKE_REQUIRED_INCLUDES ${CMAKE_INCLUDE_PATH} ${CMAKE_INCLUDE_PATH}/mingw )
    endif(MSVC)
endif(WIN32)

set( CMAKE_REQUIRED_LIBRARIES ${CMAKE_REQUIRED_LIBRARIES} ${FREETYPE_LIBRARIES} ${LIBXML2_LIBRARIES} )
set( CMAKE_REQUIRED_INCLUDES ${CMAKE_REQUIRED_INCLUDES} ${FREETYPE_INCLUDE_DIR} ${LIBXML2_INCLUDE_DIR} )
if( EXPAT_FOUND )
    set( CMAKE_REQUIRED_LIBRARIES ${CMAKE_REQUIRED_LIBRARIES} ${EXPAT_LIBRARY} )
    set( CMAKE_REQUIRED_INCLUDES ${CMAKE_REQUIRED_INCLUDES} ${EXPAT_INCLUDE_DIR} )
endif( EXPAT_FOUND )
check_include_file( "dirent.h" HAVE_DIRENT_H )
check_include_file( "dlfcn.h" HAVE_DLFCN_H )
check_include_file( "fcntl.h" HAVE_FCNTL_H )
check_include_file( "inttypes.h" HAVE_INTTYPES_H )
check_include_file( "memory.h" HAVE_MEMORY_H )
check_include_file( "ndir.h" HAVE_NDIR_H )
check_include_file( "stdint.h" HAVE_STDINT_H )
check_include_file( "stdlib.h" HAVE_STDLIB_H )
check_include_file( "strings.h" HAVE_STRINGS_H )
check_include_file( "string.h" HAVE_STRING_H )
check_include_file( "sys/dir.h" HAVE_SYS_DIR_H )
check_include_file( "sys/ndir.h" HAVE_SYS_NDIR_H )
check_include_file( "sys/stat.h" HAVE_SYS_STAT_H )
check_include_file( "sys/types.h" HAVE_SYS_TYPES_H )
check_include_file( "unistd.h" HAVE_UNISTD_H )
check_include_file( "xmlparse.h" HAVE_XMLPARSE_H )

check_function_exists( chsize HAVE_CHSIZE )
check_function_exists( _doprnt HAVE_DOPRNT )
check_function_exists( ftruncate HAVE_FTRUNCATE )
check_function_exists( FT_Get_BDF_Property HAVE_FT_GET_BDF_PROPERTY )
check_function_exists( FT_Get_Next_Char HAVE_FT_GET_NEXT_CHAR )
check_function_exists( FT_Get_PS_Font_Info HAVE_FT_GET_PS_FONT_INFO )
check_function_exists( FT_Get_X11_Font_Format HAVE_FT_GET_X11_FONT_FORMAT )
check_function_exists( FT_Has_PS_Glyph_Names HAVE_FT_HAS_PS_GLYPH_NAMES )
check_function_exists( geteuid HAVE_GETEUID )
check_function_exists( getopt HAVE_GETOPT )
check_function_exists( getopt_long HAVE_GETOPT_LONG )
check_function_exists( getpagesize HAVE_GETPAGESIZE )
check_function_exists( getuid HAVE_GETUID )
check_function_exists( link HAVE_LINK )
check_function_exists( lrand48 HAVE_LRAND48 )
check_function_exists( memmove HAVE_MEMMOVE )
check_function_exists( memset HAVE_MEMSET )
check_function_exists( mkstemp HAVE_MKSTEMP )
check_function_exists( mmap HAVE_MMAP )
check_function_exists( rand HAVE_RAND )
check_function_exists( random HAVE_RANDOM )
check_function_exists( strchr HAVE_STRCHR )
check_function_exists( strrchr HAVE_STRRCHR )
check_function_exists( strtol HAVE_STRTOL )
check_function_exists( sysconf HAVE_SYSCONF )
check_function_exists( vprintf HAVE_VPRINTF )
check_function_exists( XML_SetDoctypeDeclHandler HAVE_XML_SETDOCTYPEDECLHANDLER )
set( FC_DEFAULT_FONTS "%WINDIR%\\fonts" )
add_definitions( -DHAVE_CONFIG_H )
add_definitions( -DFONTCONFIG_PATH="\\"${CMAKE_INSTALL_PREFIX}/etc/fonts\\"" )
set( FC_CACHEDIR "\"%TEMP%\\fc_cache\"" )
configure_file( ${CMAKE_CURRENT_SOURCE_DIR}/config.h.cmake ${CMAKE_CURRENT_BINARY_DIR}/config.h )
configure_file( ${CMAKE_CURRENT_SOURCE_DIR}/fonts.conf.cmake ${CMAKE_CURRENT_BINARY_DIR}/fonts.conf )
install( FILES ${CMAKE_CURRENT_BINARY_DIR}/fonts.conf DESTINATION etc/fonts )
